Appalach: Data for streamflow gaging stations in Appalachia
Description
Site characteristics and sample $L$-moments of annual maximum streamflow
for 104 gaging stations in Appalachia.source
The file appalach.dat in the LMOMENTS Fortran package (Hosking, 1996).Details
The data in columns lat, long, area and elev,
and the streamflow data used to compute the sample $L$-moments,
were obtained from Hydrodata CD-ROMs (Hydrosphere, 1993),
which reproduce data from the U.S. Geological Survey's WATSTORE data files.References
Hydrosphere (1993).
Hydrodata CD-ROMs, vol. 4.0: USGS peak values.
Hydrosphere Data Products, Boulder, Colo.
Hosking, J. R. M. (1996).
Fortran routines for use with the method of $L$-moments, Version 3.
Research Report RC20525, IBM Research Division, Yorktown Heights, N.Y.